@@ -1,6 +1,6 @@
 package Fennec::Assert;
 BEGIN {
-  $Fennec::Assert::VERSION = '0.030';
+  $Fennec::Assert::VERSION = '0.031';
 }
 use strict;
 use warnings;
@@ -16,7 +16,7 @@ use Try::Tiny;
 use Fennec::Util::TBOverride;
 use Carp qw/confess croak carp cluck/;
 use Scalar::Util 'blessed';
-use Exporter::Declare ':extend';
+use Fennec::Exporter::Declare ':extend';
 use Fennec::Util qw/test_caller/;
 
 our @EXPORT = qw/tb_wrapper result diag test_caller note/;
